@@ -2,7 +2,6 @@ import time
 
 from django import forms
 from django.conf import settings
-from django.contrib.auth import get_user_model
 from django.contrib.contenttypes.models import ContentType
 from django.forms.util import ErrorDict
 from django.utils.crypto import salted_hmac, constant_time_compare
@@ -16,8 +15,6 @@ from .models import Comment
 from .settings import COMMENT_PLACEHOLDER, COMMENT_MAX_LENGTH
 
 
-UserModel = get_user_model()
-
 
 class CommentSecurityForm(forms.Form):
     """
@@ -100,11 +97,11 @@ class CommentDetailsForm(CommentSecurityForm):
     """
     Handles the specific details of the comment (name, comment, etc.).
     Requires user to be authenticated, because only a fool would allow unauthenticated users to comment.
-    
+
     """
     #text = forms.CharField(label=_('Comment'), widget=forms.Textarea, max_length=COMMENT_MAX_LENGTH)
     text = forms.CharField(
-        label='', 
+        label='',
         widget=forms.Textarea(attrs={'tabindex': '1', 'placeholder': COMMENT_PLACEHOLDER}),
         max_length=COMMENT_MAX_LENGTH,
     )
